/*****************************************************************************
 * 
 * Types and declarations used in the PaceMaker plug-in
 *
 * Copyright (C) Olli Parviainen, oparviai@iki.fi
 * File created  : 07/2000
 *
 * $Id: pacemaker_plugin.h 328 2015-10-21 05:37:10Z olli $
 *
 * License:
 *
 * PaceMaker plug-in for Winamp2 
 * Copyright (c) Olli Parviainen
 *
 * This source code file can be freely used, modified and further distributed.
 *
 * WWW: http://www.iki.fi/oparviai/pacemaker
 *
 *****************************************************************************/


#ifndef PACEMAKER_PLUGIN_H
#define PACEMAKER_PLUGIN_H

#include <windows.h>

typedef unsigned int    uint;

#define FALSE   0
#define TRUE    1

/// number of available precision levels, in range of 10.0 .. 0.01
#define NUM_PRECISIONLEVELS   4


/// Note: if the 'VM_APP' define isn't available, it's value is 32768

/// Win32 messages for controlling PaceMaker plug-in behaviour from external
/// programs. See an example application for hints on using the messages.

/// returns a magic number identifying that this really is 
/// PaceMaker library = 0x1770 (ahem, 'OLLI' in mirror letters...)
#define PM_IDENTIFY             WM_APP + 0

/// Returns the PaceMaker plug-in version number.
#define PM_GETREVISION          WM_APP + 1

/// enables/disables PaceMaker window shadow mode,
/// lParam = enable/disable, disable = 0
#define PM_ENABLE_SHADOWMODE    WM_APP + 2

/// enables/disables sound tweaking, 
/// lParam = enable/disable, disable = 0
#define PM_ENABLE_TWEAKING      WM_APP + 3

/// resets tempo, pitch & speed settings to zeroes
#define PM_RESET                WM_APP + 5

/// Changes the tempo setting. Notice that the new setting is rounded to comply
/// with the current tempo precision setting (see PM_SET_PRECISION for how to
/// change the precision settings)
///
/// lParam = new tempo setting, valid range is 
///          -50*SCALE .. +100*SCALE (eqv. to -50% .. +100%)
#define PM_SET_TEMPO            WM_APP + 6

/// Changes the pitch setting. Notice that the new setting is rounded to comply
/// with the current pitch precision setting (see PM_SET_PRECISION for how to
/// change the precision settings)
///
/// lParam = new pitch setting in semitones, valid range is
///          -12.0*SCALE .. +12.0*SCALE (eqv. to -12 .. +12 steps)
#define PM_SET_PITCH            WM_APP + 7

/// Changes the speed setting. Notice that the new setting is rounded to comply
/// with the current speed precision setting (see PM_SET_PRECISION for how to
/// change the precision settings)
///
/// lParam = new speed setting, valid range is 
///          -50*SCALE .. +100*SCALE (eqv. to -50% .. +100%)
#define PM_SET_SPEED            WM_APP + 8

/// Sets control precisions. Notice that when changing the PaceMaker plug-in 
/// control settings via the messages, the new setting level is rounded to 
/// comply with the active precision setting of that control.
///
/// wParam = control number, 0 = tempo, 1 = pitch, 2 = speed
/// lParam = new precision, value of '0' means precision of '10.0', 
///          1 => 1.0, 2 => 0.1 and 3 =>0.01
#define PM_SET_PRECISION        WM_APP + 9

/// Checks if PaceMaker plug-in is registered or not. Notice that 
/// registering is required for commercial use.
///
/// Returns non-zero if PaceMaker plug-in has been registred, or zero if
/// not registered.
#define PM_IS_REGISTERED        WM_APP + 10

/// Set voice cancel on / off.
///
/// wParam = enable/disable voice cancel. 0 = disable, 1 = enable.
#define PM_ENABLE_VOICECANCEL   WM_APP + 11

/// Get PaceMaker window shadow mode state, see PM_ENABLE_SHADOWMODE
#define PM_GET_SHADOWMODE       WM_APP + 12

/// Get sound tweaking enabled/disabled state, see PM_ENABLE_TWEAKING
#define PM_GET_TWEAKING_MODE    WM_APP + 13

/// Get tempo setting value, see PM_SET_TEMPO
#define PM_GET_TEMPO            WM_APP + 14

/// Get pitch setting value, see PM_SET_PITCH
#define PM_GET_PITCH            WM_APP + 15

/// Get speed setting value, see PM_SET_SPEED
#define PM_GET_SPEED            WM_APP + 16

/// Get voice cancel on / off state, see PM_ENABLE_VOICECANCEL.
/// Supported in PaceMaker version 2.6 onwards
#define PM_GET_VOICECANCEL      WM_APP + 17

/// Sets voice cancel algorithm to use. 
/// wParam value defines used algorithm as in PM_VOICECANCEL_... defines.
/// as below.
/// Supported in PaceMaker version 2.6 onwards
#define PM_SET_VOICECANCEL_MODE     WM_APP + 18

#define PM_VOICECANCEL_BASIC            0   ///< Basic algorithm
#define PM_VOICECANCEL_ADVANCED         1   ///< Advanced stereo algorithm
#define PM_VOICECANCEL_LEFT_CHANNEL     2   ///< Play left channel only
#define PM_VOICECANCEL_RIGHT_CHANNEL    3   ///< Basic right channel only

/// Returns currently used voice cancel algorithm, see
/// PM_VOICECANCEL_ defines for supported modes.
/// This message is supported from PaceMaker versions 2.6 onwards
#define PM_GET_VOICECANCEL_MODE     WM_APP + 19

/// Returns handle of Winamp window that opened this PaceMaker instance 
/// This message is supported from PaceMaker versions 2.7.3 onwards
#define PM_GET_PARENT_WINDOW        WM_APP + 20

/// A constant for scaling non-integer control values
#define SCALE       1000

#endif
